@@ -5,7 +5,7 @@ import subprocess
 from pathlib import Path
 
 # Paths.
-from nlab_inf_engine_scripts.functions import create_temp_dir, symlink
+from nlab_inf_engine_scripts.functions import create_dir, symlink
 
 INF_ENGINE_PATH_BIN = "bin/"
 INF_ENGINE_PATH_CONF = "conf/"
@@ -166,9 +166,7 @@ class InfEngineServerEngine:
         INF_ENGINE_FILE_DLDATA_VAR = f"{db_name}.ie2"
         INF_ENGINE_LINK_DLDATA_VAR = INF_ENGINE_PATH_DLDATA + INF_ENGINE_FILE_DLDATA_VAR
 
-        # dldata_obj = create_temp_dir(self._engine_dir / INF_ENGINE_PATH_DLDATA)
-        # dldata_path = Path(dldata_obj.name)
-        dldata_path = create_temp_dir(self._engine_dir / INF_ENGINE_PATH_DLDATA)
+        dldata_path = create_dir(self._engine_dir / INF_ENGINE_PATH_DLDATA)
 
         self._logger.debug(f"dldata_path: {dldata_path}")
 
